==> eel-1.1.1.tar.gz: eel-1.1.1/eel/eel.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* eel.h

   Copyright (C) 2001 Eazel, Inc.

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Authors: Maciej Stachowiak <mjs@eazel.com>
*/

#ifndef EEL_H
#define EEL_H

#include <eel/eel-art-extensions.h>
#include <eel/eel-art-gtk-extensions.h>
#include <eel/eel-background.h>
#include <eel/eel-caption-table.h>
#include <eel/eel-caption.h>
#include <eel/eel-clist.h>
#include <eel/eel-ctree.h>
#include <eel/eel-dateedit-extensions.h>
#include <eel/eel-ellipsizing-label.h>
#include <eel/eel-enumeration.h>
#include <eel/eel-features.h>
#include <eel/eel-font-picker.h>
#include <eel/eel-gconf-extensions.h>
#include <eel/eel-gdk-extensions.h>
#include <eel/eel-gdk-pixbuf-extensions.h>
#include <eel/eel-generous-bin.h>
#include <eel/eel-glib-extensions.h>
#include <eel/eel-gnome-extensions.h>
#include <eel/eel-graphic-effects.h>
#include <eel/eel-gtk-container.h>
#include <eel/eel-gtk-extensions.h>
#include <eel/eel-gtk-macros.h>
#include <eel/eel-image-chooser.h>
#include <eel/eel-image-table.h>
#include <eel/eel-image-with-background.h>
#include <eel/eel-image.h>
#include <eel/eel-labeled-image.h>
#include <eel/eel-list-column-title.h>
#include <eel/eel-list.h>
#include <eel/eel-password-dialog.h>
#include <eel/eel-preferences-box.h>
#include <eel/eel-preferences-group.h>
#include <eel/eel-preferences-item.h>
#include <eel/eel-preferences-pane.h>
#include <eel/eel-preferences.h>
#include <eel/eel-radio-button-group.h>
#include <eel/eel-region.h>
#include <eel/eel-self-checks.h>
#include <eel/eel-smooth-widget.h>
#include <eel/eel-stock-dialogs.h>
#include <eel/eel-string-list.h>
#include <eel/eel-string-picker.h>
#include <eel/eel-string.h>
#include <eel/eel-text-caption.h>
#include <eel/eel-types.h>
#include <eel/eel-vfs-extensions.h>
#include <eel/eel-viewport.h>
#include <eel/eel-wrap-table.h>
#include <eel/eel-xml-extensions.h>

#endif /* EEL_H */

==> eel-1.1.3.tar.gz: eel-1.1.3/eel/eel.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* eel.h

   Copyright (C) 2001 Eazel, Inc.

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Authors: Maciej Stachowiak <mjs@eazel.com>
*/

#ifndef EEL_H
#define EEL_H

#include <eel/eel-art-extensions.h>
#include <eel/eel-art-gtk-extensions.h>
#include <eel/eel-background.h>
#include <eel/eel-caption-table.h>
#include <eel/eel-caption.h>
#include <eel/eel-clist.h>
#include <eel/eel-ctree.h>
#include <eel/eel-dateedit-extensions.h>
#include <eel/eel-ellipsizing-label.h>
#include <eel/eel-enumeration.h>
#include <eel/eel-features.h>
#include <eel/eel-font-picker.h>
#include <eel/eel-gconf-extensions.h>
#include <eel/eel-gdk-extensions.h>
#include <eel/eel-gdk-pixbuf-extensions.h>
#include <eel/eel-generous-bin.h>
#include <eel/eel-glib-extensions.h>
#include <eel/eel-gnome-extensions.h>
#include <eel/eel-graphic-effects.h>
#include <eel/eel-gtk-container.h>
#include <eel/eel-gtk-extensions.h>
#include <eel/eel-gtk-macros.h>
#include <eel/eel-image-chooser.h>
#include <eel/eel-image-table.h>
#include <eel/eel-labeled-image.h>
#include <eel/eel-list-column-title.h>
#include <eel/eel-list.h>
#include <eel/eel-pango-extensions.h>
#include <eel/eel-password-dialog.h>
#include <eel/eel-preferences-box.h>
#include <eel/eel-preferences-group.h>
#include <eel/eel-preferences-item.h>
#include <eel/eel-preferences-pane.h>
#include <eel/eel-preferences.h>
#include <eel/eel-radio-button-group.h>
#include <eel/eel-region.h>
#include <eel/eel-self-checks.h>
#include <eel/eel-stock-dialogs.h>
#include <eel/eel-string-list.h>
#include <eel/eel-string-picker.h>
#include <eel/eel-string.h>
#include <eel/eel-text-caption.h>
#include <eel/eel-types.h>
#include <eel/eel-vfs-extensions.h>
#include <eel/eel-wrap-table.h>
#include <eel/eel-xml-extensions.h>

#endif /* EEL_H */
